@@ -26,6 +26,10 @@ GList* composing_game_get_actors_in_track(){
 
 ClutterActor* timeline_star_actor;
 ClutterActor* objects_in_this_stage;
+extern ClutterActor* play_button;
+extern ClutterActor* mentor;
+extern ClutterActor* to_main_menu;
+extern ClutterActor* back_to_theme_selection; 
 
 static void on_timeline_completed(ClutterTimeline *timeline,  gpointer data) {
   //printf("star reached end\n");
@@ -193,6 +197,18 @@ void start_theme() {
 
     clutter_actor_raise_top(drop_area);
     clutter_actor_show (drop_area);
+
+    clutter_actor_set_reactive(back_to_theme_selection, TRUE);
+    clutter_actor_raise_top(back_to_theme_selection);
+    clutter_actor_show (back_to_theme_selection);
+
+    clutter_actor_set_reactive(mentor, TRUE);
+    clutter_actor_raise_top(mentor);
+    clutter_actor_show (mentor);
+
+    clutter_actor_set_reactive(play_button, TRUE);
+    clutter_actor_raise_top(play_button);
+    clutter_actor_show (play_button);
 }
 
 
@@ -224,7 +240,7 @@ void composing_game_init_games() {
         objects_group = clutter_group_new();
         object_create_stage_object_group (objects_group, chum_get_theme_folder(i));
 
-        button_create_buttons (objects_group);
+        //button_create_buttons (objects_group); //This is not used anymore.
 
         //ClutterGroup is not passed forward. Unroll it to GList.
         int j;
@@ -268,17 +284,11 @@ chum_change_theme(value);
 chum_go_screen(SCREEN_COMPOSING);
 }
 
-
-static void from_theme_selection_to_game_selection(){
-chum_go_screen(SCREEN_GAME_SELECTION);
-}
-
 GList *group; /*There are variable number of themes and border lines.*/
 ClutterActor *borders;  /*This is outer border*/
-ClutterActor *back_to_mainmenu; /*Button back to main_menu.*/
 
 gboolean composing_game_is_menu_initialized(){
-  return (back_to_mainmenu != NULL); //Last initialized actor.
+  return (borders != NULL); //Last initialized actor.
 }
 
 void show_theme_selection() {
@@ -296,9 +306,13 @@ void show_theme_selection() {
     clutter_actor_raise_top(borders);
     clutter_actor_show (borders);
 
-    clutter_actor_set_reactive(back_to_mainmenu, TRUE);
-    clutter_actor_raise_top(back_to_mainmenu);
-    clutter_actor_show (back_to_mainmenu);
+    clutter_actor_set_reactive(to_main_menu, TRUE);
+    clutter_actor_raise_top(to_main_menu);
+    clutter_actor_show (to_main_menu);
+
+    clutter_actor_set_reactive(mentor, TRUE);
+    clutter_actor_raise_top(mentor);
+    clutter_actor_show (mentor);
 }
 
 void composing_game_init_theme_selection() {
@@ -351,13 +365,4 @@ void composing_game_init_theme_selection() {
   clutter_actor_hide (borders);
   clutter_container_add_actor (CLUTTER_CONTAINER (stage), borders);
 
-  //Back to main-menu button.
-  back_to_mainmenu = config_get_configured_actor(NULL,"house");
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), back_to_mainmenu);
-  clutter_actor_set_position (back_to_mainmenu, 720, 5); 
-  clutter_actor_set_size (back_to_mainmenu, 66, 60);
-  clutter_actor_hide (back_to_mainmenu);
-  clutter_actor_set_name(back_to_mainmenu, "back_to_mainmenu");
-  clutter_actor_set_reactive(back_to_mainmenu, FALSE);
-  g_signal_connect (back_to_mainmenu, "button-press-event", G_CALLBACK (from_theme_selection_to_game_selection),NULL);
 }
