@@ -7,8 +7,8 @@ This file is for clutter based gui.
 #ifndef _INSTRUMENT_TESTING_H_
 #define _INSTRUMENT_TESTING_H_
 
-void start_test_instrument(ClutterActor *actor, ClutterEvent *event, gpointer data);
-void start_slider(ClutterActor *actor, ClutterEvent *event, gpointer data);
+void start_test_instrument(int type);
+void start_test_slider(int type);
 void *start_reading_joystick();
 
 #endif /* _INSTRUMENT_TESTING_H_ */
